<?php
class GeoUser{
    /**
     * Get a Yahoo Map as PNG image
     *
     * @param string $appid
     * @param float $latitude
     * @param float $longitude
     * @param int $imageHeight
     * @param int $imageWidth
     * @return string map of html format
     * @throws Exception cannot get content from yahoo map service
     */
    public static function getPngMap($appid, $latitude, $longitude, $imageHeight, $imageWidth){

        $request  = 'http://local.yahooapis.com/MapsService/V1/mapImage';
        $request .= '?appid='.$appid;
        $request .= '&latitude='.$latitude;
        $request .= '&longitude='.$longitude;
        $request .= '&image_height='.$imageHeight;
        $request .= '&image_width='.$imageWidth;
        $request .= '&output=php';

        $resource = curl_init($request);
        curl_setopt($resource,CURLOPT_RETURNTRANSFER, TRUE);

        //var_dump($request);

        if($response = curl_exec($resource)){
            
            curl_close($resource);
            $phpobj = unserialize($response);
            $url = $phpobj['Result'];
            //var_dump($phpobj);
            $map = '<img src="' .$url .'" />';
            return $map;
        }else
        throw new Exception('Cannot get content from '.$request);
         
    }

    /**
     * Retrieve user's IP address from geouser table
     *
     * @param int $uid
     * @return string IP address
     * @throws Exception IP address of the user cannot be found
     */
    public static function getUserIP($uid){

        $addr = null;
        if($result = db_query("select addr from geouser where uid = %d", $uid) ){
            if($geouser = db_fetch_array($result)){

                $addr = $geouser['addr'];
            }
        }
        if($addr == null)
        throw new Exception('IP address of the user cannot be found.');
        else
        return $addr;
    }
    
    /**
     * Retrieve geographic information from IP database
     *
     * @param string $path || path of IP database
     * @param string $addr || IP address
     * @return Net_GeoIP_Location || The full location record
     */
    public static function getGeoCity($path, $addr){
        
        $location = null;
        require_once('GeoIP.php');
        try{
        $geo = new Net_GeoIP($path);
        $location = $geo->lookupLocation($addr);
        }catch(Exception $e){
            
           drupal_set_message($e->getMessage(),'error');
        }
        
        return $location;
    }

}





